zmats
==============================
[//]: # (Badges)
[![Travis Build Status](https://travis-ci.com/ReactionMechanismGenerator/zmats.svg?branch=master)](https://travis-ci.com/ReactionMechanismGenerator/zmats)
[![codecov](https://codecov.io/gh/ReactionMechanismGenerator/zmats/branch/master/graph/badge.svg)](https://codecov.io/gh/ReactionMechanismGenerator/zmats/branch/master)
[![MIT license](http://img.shields.io/badge/license-MIT-brightgreen.svg)](http://opensource.org/licenses/MIT)

A Z-matrix module written in Python

### Copyright

Copyright (c) 2020, Alon Grinberg Dana


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.1.
